import QtQuick
import QtQuick3D
import Quick3DAssets.FridgeFull 1.0

Node {
    id: root
    state: "FridgeClose"
    property int fridgeSts: 0

    onFridgeStsChanged: switch(fridgeSts){
                        case 0:
                            root.state = "FridgeClose"
                            break
                        case 1:
                            root.state = "DoorAopen"
                            break
                        case 2:
                            root.state = "DoorBopen"
                            break
                        case 3:
                            root.state = "AllDorsOpen"
                            break
                        }

    // Materials
    // end of Materials

    Node {
        id: rootNode
        Node {
            id: empty
            rotation: Qt.quaternion(0.707107, -0.707107, 0, 0)
            scale.x: 100
            scale.y: 100
            scale.z: 100
            Model {
                id: refrigerator_LOD0
                source: "meshes/refrigerator_LOD0.mesh"
                materials: [body,body]
                Model {
                    id: door_A_LOD0
                    x: 0.331683
                    y: -0.312766
                    z: 2.00997
                    source: "meshes/door_A_LOD0.mesh"
                    materials: door_1
                }
                Model {
                    id: door_B_LOD0
                    x: 0.331683
                    y: -0.312766
                    z: 2.00997
                    source: "meshes/door_B_LOD0.mesh"
                    materials: door_2
                }
            }
        }
    }

    Node {
        id: __materialLibrary__

        DefaultMaterial {
            id: fridgeMat
            lightProbe: hdr_HVAC_day
            lighting: DefaultMaterial.NoLighting
            depthDrawMode: Material.AlwaysDepthDraw
            objectName: "material__38_material"
            diffuseMap: Texture {
                source: "maps/Refrigerator_LOD0_Beauty.png"
                pivotU: 0.5
                pivotV: 0.5
                generateMipmaps: true
                mipFilter: Texture.Linear
            }
        }

        DefaultMaterial {
            id: doorAMat
            lighting: DefaultMaterial.NoLighting
            depthDrawMode: Material.AlwaysDepthDraw
            objectName: "material__38_material"
            diffuseMap: Texture {
                source: "maps/Door_A_LOD0_Beauty.png"
                pivotU: 0.5
                pivotV: 0.5
                generateMipmaps: true
                mipFilter: Texture.Linear
            }
        }

        DefaultMaterial {
            id: doorBMat
            lighting: DefaultMaterial.NoLighting
            depthDrawMode: Material.AlwaysDepthDraw
            objectName: "material__38_material"
            diffuseMap: Texture {
                source: "maps/Door_B_LOD0_Beauty.png"
                pivotU: 0.5
                pivotV: 0.5
                generateMipmaps: true
                mipFilter: Texture.Linear
            }
        }

        PrincipledMaterial {
            id: body
            specularReflectionMap: refrigerator_LOD0_Beauty
            metalness: 0.1
            roughness: 0.1
            lightProbe: hdr_HVAC_day
            baseColorMap: refrigerator_LOD0_Beauty
            baseColor: "#ffffff"
            objectName: "New Material"

            Texture {
                id: hdr_HVAC_day
                source: "../../../content/images/hdr_HVAC_day.hdr"
            }

            Texture {
                id: refrigerator_LOD0_Beauty
                source: "../../../content/images/Refrigerator_LOD0_Beauty.png"
            }
        }

        PrincipledMaterial {
            id: door_1
            specularReflectionMap: door_A_LOD0_Beauty
            baseColor: "#ffffff"
            lightProbe: hdr_HVAC_day
            baseColorMap: door_A_LOD0_Beauty
            metalness: 0.1
            objectName: "New Material"
            roughness: 0.1

            Texture {
                id: door_A_LOD0_Beauty
                source: "../../../content/images/Door_A_LOD0_Beauty.png"
            }
        }

        PrincipledMaterial {
            id: door_2
            specularReflectionMap: door_B_LOD0_Beauty
            baseColor: "#ffffff"
            lightProbe: hdr_HVAC_day
            baseColorMap: door_B_LOD0_Beauty
            metalness: 0.1
            objectName: "New Material"
            roughness: 0.1

            Texture {
                id: door_B_LOD0_Beauty
                source: "../../../content/images/Door_B_LOD0_Beauty.png"
            }
        }
    }
    states: [
        State {
            name: "FridgeClose"
        },
        State {
            name: "DoorAopen"

            PropertyChanges {
                target: door_A_LOD0
                eulerRotation.z: 100
            }
        },
        State {
            name: "DoorBopen"

            PropertyChanges {
                target: door_B_LOD0
                eulerRotation.z: 90
            }
        },
        State {
            name: "AllDorsOpen"

            PropertyChanges {
                target: door_A_LOD0
                eulerRotation.z: 100
            }

            PropertyChanges {
                target: door_B_LOD0
                eulerRotation.z: 90
            }
        }
    ]
    transitions: [
        Transition {
            id: allDoors
            ParallelAnimation {
                SequentialAnimation {
                    PauseAnimation {
                        duration: 150
                    }

                    PropertyAnimation {
                        target: door_A_LOD0
                        property: "eulerRotation.z"
                        duration: 300
                    }
                }
            }

            ParallelAnimation {
                SequentialAnimation {
                    PauseAnimation {
                        duration: 200
                    }

                    PropertyAnimation {
                        target: door_B_LOD0
                        property: "eulerRotation.z"
                        duration: 400
                    }
                }
            }
            to: "AllDorsOpen"
            from: "FridgeClose"
            reversible: true
        },
        Transition {
            id: doorA
            ParallelAnimation {
                SequentialAnimation {
                    PauseAnimation {
                        duration: 150
                    }

                    PropertyAnimation {
                        target: door_A_LOD0
                        property: "eulerRotation.z"
                        duration: 550
                    }
                }
            }
            to: "DoorAopen"
            from: "FridgeClose"
            reversible: true
        },
        Transition {
            id: doorB
            ParallelAnimation {
                SequentialAnimation {
                    PauseAnimation {
                        duration: 150
                    }

                    PropertyAnimation {
                        target: door_B_LOD0
                        property: "eulerRotation.z"
                        duration: 550
                    }
                }
            }
            to: "DoorBopen"
            from: "FridgeClose"
            reversible: true
        },
        Transition {
            id: doorAB
            ParallelAnimation {
                SequentialAnimation {
                    PropertyAnimation {
                        target: door_A_LOD0
                        property: "eulerRotation.z"
                        duration: 500
                    }
                }
            }

            ParallelAnimation {
                SequentialAnimation {
                    PropertyAnimation {
                        target: door_B_LOD0
                        property: "eulerRotation.z"
                        duration: 500
                    }
                }
            }
            to: "DoorAopen"
            from: "DoorBopen"
            reversible: true
        }
    ]
}

/*##^##
Designer {
    D{i:0}D{i:28;transitionDuration:2000}D{i:37;transitionDuration:2000}D{i:42;transitionDuration:2000}
D{i:47;transitionDuration:2000}D{i:16}D{i:18}
}
##^##*/
