import QtQuick
import QtQuick.Controls

Item {
    id: root
    width:390
    height: 800

    property alias title: titleText.text
    property int temperatureValue: startValue
    property int startValue: 0
    property int endValue: 5
    property var values: []
    property var colors: []
    property color lineColor: "#00BDFF"
    property bool isFreezer: false
    property int indexValue: 3


    signal sliderValueChanged(int value)



    Text {
        id: titleText
        y: 137
        width: 92
        height: 19
        visible: true
        color: "#FFFFFF"
        font.pixelSize: 16
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        wrapMode: Text.NoWrap
        anchors.horizontalCenter: parent.horizontalCenter
        font.weight: Font.Black
        font.family: "Inter"
    }


       Repeater{
            model: root.values
            delegate: SliderTick{
                x: 10
                y: (isFreezer)?625-(70*index):625-(85*index)
                value: values[index]
                active: (root.temperatureValue===value)
                textColor: colors[index]

            }
        }



    Image{
        id: img
        anchors.horizontalCenter: parent.horizontalCenter
        anchors.horizontalCenterOffset: 55
        anchors.top: titleText.bottom
        anchors.topMargin: 55
        width: 76
        height: 507
        source: "../images/"+((isFreezer)?"freezer":"fridge")+"/position_"+indexValue+"_style_dark.png"
    }




    Slider{
        id: slider
        anchors.top: img.top
        anchors.topMargin: 15
        anchors.horizontalCenter: img.horizontalCenter
        width: 76
        height: 480
        orientation: Qt.Vertical
        snapMode: RangeSlider.SnapOnRelease
        stepSize: utils.celsiusUnit?1:2
        from: root.startValue
        to: root.endValue
        value: root.temperatureValue

        background: Item{}
        handle: Item{}

        onMoved: {

            if(slider.value !== root.temperatureValue){
                root.sliderValueChanged(value)
            }

        }
    }


    onTemperatureValueChanged: {

        var tmp = values.indexOf(temperatureValue)

        indexValue = Math.max(0, tmp)

    }



}


