import QtQuick 2.15
import QtQuick.Controls 2.15
import QtQuick3D
import Quick3DAssets.FridgeFull 1.0
import Quick3DAssets.FridgeFull_Baked_SeparatedMaterials 1.0


Item {
    id: root
    width: 890
    height: 720
    state: "state_doors_closed"

    View3D {
        id: view3D
        anchors.right: parent.right
        anchors.rightMargin: 15
        y: 8
        width: 883
        height: 1064
        environment: sceneEnvironment
        SceneEnvironment {
            id: sceneEnvironment
            probeExposure: 3
            lightProbe: hdr_HVAC_day
            tonemapMode: SceneEnvironment.TonemapModeHejlDawson
            antialiasingQuality: SceneEnvironment.High
            antialiasingMode: SceneEnvironment.MSAA

            Texture {
                id: hdr_HVAC_day
                source: "images/hdr_HVAC_day.hdr"
                mappingMode: Texture.LightProbe
            }
        }

        Node {
            id: scene

            PerspectiveCamera {
                id: sceneCamera
                x: -1
                y: 26
                fieldOfView: 66
                clipFar: 100
                z: 89.42003
            }


            FridgeFull{
                id: fridgeFull
                eulerRotation.y: slider.value
                scale.z: 0.3
                scale.y: 0.3
                scale.x: 0.3
                fridgeSts: 0

                PointLight {
                    id: lightPoint
                    x: -2.067
                    y: 119.132
                    color: "#dfecff"
                    z: -0
                }

                Model {
                    id: plane
                    source: "#Rectangle"
                    eulerRotation.x: -90
                    materials: defaultMaterial
                }
            }
        }
    }

    Item {
        id: __materialLibrary__

        DefaultMaterial {
            id: defaultMaterial
            opacity: 0.3
            diffuseColor: "#1d1d1d"
            opacityMap: freeze_shadow
            objectName: "New Material"

            Texture {
                id: freeze_shadow
                source: "images/freeze_shadow.png"
            }
        }
    }

    Slider {
        id: slider
        x: 1161
        y: 126
        width: 641
        height: 747
        opacity: 0
        to: 80
        from: -80
        value: 0
    }

    onStateChanged: {
        if (state === "state_doors_closed") {
            slider.value = 0;
        } else if (state === "state_doors_opened") {
            slider.value = 26;
        }
    }




    states: [
        State {
            name: "state_doors_closed"

            PropertyChanges {
                target: fridgeFull
                fridgeSts: 0
            }



        },
        State {
            name: "state_doors_opened"

            PropertyChanges {
                target: fridgeFull
                x: -9
                y: -4
                eulerRotation.y: slider.value
                fridgeSts: 3
            }

            PropertyChanges {
                target: slider
                value: 26
            }

        },
        State {
            name: "state_fridge_opened"

            PropertyChanges {
                target: fridgeFull
                x: -9
                y: -2
                eulerRotation.y: slider.value
                fridgeSts: 1
            }

            PropertyChanges {
                target: lightPoint
                x: -2.067
                y: 150.384
                brightness: 3.92
                z: 38.31788
            }

            PropertyChanges {
                target: slider
                value: 30
            }
        },
        State {
            name: "state_freezer_opened"

            PropertyChanges {
                target: fridgeFull
                x: -8
                eulerRotation.y: slider.value
                fridgeSts: 2
            }

            PropertyChanges {
                target: slider
                value: 20
            }

        }
    ]
    transitions: [
        Transition {
            id: transition
            ParallelAnimation {
                SequentialAnimation {
                    PropertyAnimation {
                        target: fridgeFull
                        property: "x"
                        duration: 1500
                    }
                }

                SequentialAnimation {
                    PropertyAnimation {
                        target: fridgeFull
                        property: "eulerRotation.y"
                        duration: 1500
                    }
                }

                SequentialAnimation {
                    PropertyAnimation {
                        target: fridgeFull
                        property: "z"
                        duration: 1500
                    }
                }

                SequentialAnimation {
                    PropertyAnimation {
                        target: fridgeFull
                        property: "y"
                        duration: 1500
                    }
                }
            }
            to: "*"
            from: "*"
        }
    ]



    function openDoors(){

        root.state = "state_doors_opened"

    }


    function openFridgeDoor(){


        root.state = "state_fridge_opened"
    }


    function openFreezerDoor(){


        root.state = "state_freezer_opened"

    }


    function closeDoors(){


        root.state = "state_doors_closed"
    }



}



/*##^##
Designer {
    D{i:0}D{i:25;transitionDuration:2000}
}
##^##*/
