import QtQuick
import QtQuick.Controls
import QtQuick.Layouts
import "./FridgeExport"

Item {
    id: root
    width: 1080
    height: 1920

    property string pageName
    property int currentPage: -1

    signal closeSelected

    state: "hidden"

    Rectangle{

        id: background
        color: "#000000"
        opacity: 0
        anchors.fill: parent

        MouseArea{

            anchors.fill: parent
            enabled: root.state==="shown"

        }

    }

    Rectangle{
        id: contentRectangle
        width: parent.width
        color: "#13182f"
        y: 1920
        height: 1800
        radius: 72


        Rectangle{

            width: parent.width
            color: contentRectangle.color
            anchors.bottom: parent.bottom
            height: 60

        }



        Text{
            width: 285
            height: 58
            x: 40
            y: 58
            horizontalAlignment:  Text.AlignLeft
            verticalAlignment: Text.AlignVCenter
            color: "#FFFFFF"
            font.pixelSize: 28
            text: root.pageName
            font.family: "inter"
            font.weight: Font.Normal
            lineHeight: 34

        }


        Close {
            id: close
            x: 992
            y: 48
            width: 48
            height: 48
            clip: true
            state: "state_size_48_Mode_Dark_Status_Active"

            MouseArea{
                id: mouseArea
                anchors.fill: parent
                anchors.margins: -15
                onClicked: {
                 if(root.currentPage === 0){
                    storagePage.closeDoors()
                 }
                 else if(root.currentPage === 1){
                    temperaturePage.closeDoors()
                 }
                    root.close()
                }



            }
        }





        StackLayout{
            anchors.fill: parent
            anchors.topMargin: 48
            //anchors.rightMargin: 48
            currentIndex: root.currentPage

            StoragePage{
                id: storagePage
            }

            TemperaturePage{
                id: temperaturePage
            }

            ShoppingPage{
                id: shoppingPage
            }

            onCurrentIndexChanged: {


                switch(currentIndex){

                case -1:{
                    temperaturePage.fridgeSelected = true
                }
                break;
                case 0:{
                    storagePage.openDoors()
                }
                break;

                case 1:{
                    temperaturePage.openFridgeDoor()

                }
                break;

              default:
                break;

                }



            }

        }

    }



    states: [
        State {
            name: "hidden"
            PropertyChanges {
                target: background
                opacity: 0
            }
            PropertyChanges {
                target: contentRectangle
                y: 1920
            }
            PropertyChanges {
                target: temperaturePage
                y: 1920
            }
        },
        State {
            name: "shown"
            PropertyChanges {
                target: background
                opacity: 0.8
            }
            PropertyChanges {
                target: contentRectangle
                y: 120
            }
        }
    ]


    transitions: Transition {
        NumberAnimation { properties: "y, opacity"; duration: 750 }

    }


    function open(){

        root.state = "shown"
    }


    function close(){

        root.state = "hidden"
      //  currentPage = -1
    }


}
