import QtQuick
import QtQuick.Controls
import "./FridgeExport"
import "./Elements"

Item {
    id: root
    width: 1080
    height: 1920

    property alias fridgeSelected: switchButton.fridgeSelected


    FridgeModel{
        id: model
        x: 93
        y: 100
    }


    Text {
        id: titleText
        y: 159
        width: 92
        height: 19
        visible: true
        color: "#FFFFFF"
        font.pixelSize: 20
        horizontalAlignment: Text.AlignHCenter
        verticalAlignment: Text.AlignVCenter
        wrapMode: Text.NoWrap
        anchors.horizontalCenter: parent.horizontalCenter
        font.weight: Font.Black
        font.family: "Inter"
        text: switchButton.fridgeSelected?qsTr("Fridge door"):qsTr("Freezer door")
    }


    Item{
        id: sliders
        y: 850
        width: 400
        height: 769
        anchors.horizontalCenter: parent.horizontalCenter


        TemperatureSlider{
            id: fridgeSlider
            anchors.fill: parent
            temperatureValue: utils.fridgeData.fridgeTemperature
            visible: switchButton.fridgeSelected
            startValue: utils.celsiusUnit?0:38
            endValue: utils.celsiusUnit?5:48
            values: utils.celsiusUnit?[0, 1, 2, 3, 4, 5]:[38, 40, 42, 44, 46, 48]
            colors: ["#0078FF", "#009EFF","#00BDFF", "#00DCFC", "#00EDD3", "#00FFA8"]

            onSliderValueChanged: function(value){
                utils.fridgeData.fridgeTemperature = value
                manager.setFridgeTemperature(0, value)
            }
        }


        TemperatureSlider{
            id: freezerSlider
            anchors.fill: parent
            temperatureValue: utils.fridgeData.freezerTemperature
            visible: !switchButton.fridgeSelected
            startValue: utils.celsiusUnit?-20:10
            endValue: utils.celsiusUnit?-14:22
            values: utils.celsiusUnit? [-20, -19, -18, -17, -16, -15, -14]:[10, 12, 14, 16, 18, 20, 22]
            colors: ["#CC00FF", "#B336FF","#9A4CFF", "#7F5AFF", "#6264FF", "#406CFF", "#0072FF"]
            isFreezer: true

            onSliderValueChanged: function(value){
                utils.fridgeData.freezerTemperature = value
                manager.setFridgeTemperature(1, value)
            }
        }



        SwitchButton{
            id: switchButton
            anchors.horizontalCenter: parent.horizontalCenter
            anchors.top: parent.top
            anchors.topMargin: 800

            onFridgeSelectedChanged: function() {

                if(fridgeSelected)
                    root.openFridgeDoor()
                else
                    root.openFreezerDoor()

            }

        }


    }


    Connections{
        target: manager
        function onFridgeTemperatureUpdated(index, value){

            if(index){

                utils.fridgeData.freezerTemperature = value
            }
            else{
                utils.fridgeData.fridgeTemperature = value
            }


        }

    }

    function openFridgeDoor(){

        model.openFridgeDoor()

    }


    function openFreezerDoor(){

        model.openFreezerDoor()

    }


    function closeDoors(){
        model.closeDoors()
    }

}
