
import QtQuick

Item {
    id: root

    property bool euroCurrency: true
    property bool celsiusUnit: true
    property bool lightMode: false
    property var devicesModel: filteredDevicesModelList
    property var shortcutsModel: shortcutsModelList
    property var notificationsModel: notificationsList
    property var thermalProfileModel: thermalProfileList
    property var dishWasherProgramsModel: dishWasherProgramsList
    property alias fullDevicesModel: devicesModelList
    property alias roomsApplianceModel: roomsAppliancesList
    property alias energyMonthsModel: energyMonthsList


    property alias dishWasherStatus: _dishWasherStatus
    property alias lightsStatus: _lightsStatus
    property alias printerStatus: _printerStatus
    property alias securityStatus: _securityStatus
    property alias weatherStatus: _weatherStatus
    property alias roomsStatus: _roomsStatus
    property alias energyStatus: _energyStatus
    property alias shortcutStatus: _shortcutStatus


    property alias fridgeData: _fridgeData
    property alias dishWasherData: _dishWasherData
    property alias thermostatData: _thermostatData


    Component.onCompleted: {

        updateDeviceModel(_roomsStatus.all)

        if(celsiusUnit){
            _fridgeData.fridgeTemperature = 3;
            _fridgeData.freezerTemperature = -17

        }

    }


    QtObject{
        id: _thermostatData
        property int currentProfileIndex: 0
        property string currentProfileName: thermalProfileList.get(currentProfileIndex).name
        property int averageTemperature: thermalProfileList.get(currentProfileIndex).rooms.get(0).temperatures.get(0).value
    }


    QtObject{
        id: _dishWasherData
        property int currentProgramIndex: 0
        property bool halfLoadOn: false
        property bool preWashOn: false
        property double delayValue: 0
        property int completion: 0
    }

    QtObject{
        id: _fridgeData
        property int fridgeTemperature: 44
        property int freezerTemperature: 16
    }


    QtObject{
        id: _shortcutStatus
        property int value: 0
        readonly property int getup: 0
        readonly property int leave: 1
        readonly property int home: 2
        readonly property int sleep: 3
    }


    QtObject{
        id: _dishWasherStatus
        property int value: 0
        readonly property int idle: 0
        readonly property int ready: 1
        readonly property int working: 2
        readonly property int pause: 3
    }


    QtObject{
        id: _lightsStatus
        property int value: 0
        readonly property int off: 0
        readonly property int relax: 1
        readonly property int bright: 2
    }


    QtObject{
        id: _printerStatus
        property int value: 0
        property int off: 0
        readonly property int ready: 1
        readonly property int printing: 2
    }

    QtObject{
        id: _securityStatus
        property int value: 0
        readonly property int off: 0
        readonly property int on: 1
    }

    QtObject{
        id: _weatherStatus
        property int value: 0
        readonly property int sunny: 0
        readonly property int cloudy: 1
        readonly property int rainy: 2
        readonly property int stormy: 3
        readonly property int snowy: 4


    }


    QtObject{
        id: _energyStatus
        property int value: 0
        readonly property int comfort: 0
        readonly property int eco: 1
    }

    QtObject{
        id: _roomsStatus
        property int value: -1
        readonly property int all: -1
        readonly property int living: 0
        readonly property int bathroom: 1
        readonly property int kitchen: 2
        readonly property int office: 3
        readonly property int bedroom: 4

        onValueChanged: root.updateDeviceModel(value)
    }


    ListModel{
        id: filteredDevicesModelList
    }


    ListModel{
        id: notificationsList
        ListElement{
            deviceName: "Dishwasher"
            messageValue: "Washing cycle completed"
            timeValue: "2 min ago"
            readValue: false

        }
        ListElement{
            deviceName: "Fridge"
            messageValue: "Door is opened"
            timeValue: "5 min ago"
            readValue: false

        }
        ListElement{
            deviceName: "Lights"
            messageValue: "Office lights turned on"
            timeValue: "3 hours ago"
            readValue: true

        }
        ListElement{
            deviceName: "Thermostat"
            messageValue: "Temperature's profile set to Kids at Home"
            timeValue: "4 hours ago"
            readValue: true

        }
        ListElement{
            deviceName: "Printer"
            messageValue: "5 pages printed"
            timeValue: "1 day ago"
            readValue: true

        }


    }


    ListModel{
        id: shortcutsModelList
        ListElement{
            name: "Get up"
            iconFilled: "Sun_filled.ui.qml"
            iconOutlined: "Sun_outline.ui.qml"
            value: 0
            description: "Warn temperature and soft lights, the best way to start the day"
        }
        ListElement{
            name: "Leave"
            iconFilled: "DoorFilled.ui.qml"
            iconOutlined: "DoorOutline.ui.qml"
            value: 1
            description: "Eco mode is active and security is on. Enjoy your day"
        }
        ListElement{
            name: "At home"
            iconFilled: "HouseFilled.ui.qml"
            iconOutlined: "HouseOutline.ui.qml"
            value: 2
            description: "Comfort mode is all you need:)"
        }
        ListElement{
            name: "Sleep"
            iconFilled: "MoonFilled.ui.qml"
            iconOutlined: "MoonOutline.ui.qml"
            value: 3
            description: "Let's turn the lights off and the security on, good night"
        }

    }


    ListModel{
        id: devicesModelList


        ListElement{
            deviceIndex: 0
            deviceName: qsTr("Shortcuts")
            deviceDescription: qsTr("Qt shortcuts control")
            deviceSource: ""
            deviceWidget: "../Apps/Shortcuts/ShortcutsWidget.qml"
            deviceRooms: []
            deviceEnabled: true
        }

        ListElement{
            deviceIndex: 1
            deviceName: qsTr("Energy")
            deviceDescription: qsTr("Qt energy control")
            deviceSource: "../Apps/Energy/EnergyApp.qml"
            deviceWidget: "../Apps/Energy/EnergyWidget.qml"
            deviceRooms: [
                ListElement{ value: 0}
            ]
            deviceEnabled: true
        }


        ListElement{
            deviceIndex: 2
            deviceName: qsTr("Fridge")
            deviceDescription: qsTr("Qt Smart Fridge")
            deviceSource: "../Apps/Fridge/FridgeApp.qml"
            deviceWidget: "../Apps/Fridge/FridgeWidget.qml"
            deviceRooms: [
                ListElement{ value: 2}
            ]
            deviceEnabled: true
        }

        ListElement{
            deviceIndex: 3
            deviceName: qsTr("Thermostat")
            deviceDescription: qsTr("Qt thermostat control")
            deviceSource: "../Apps/Thermostat/ThermostatApp.qml"
            deviceWidget: "../Apps/Thermostat/ThermostatWidget.qml"
            deviceRooms: [
                ListElement{ value: 1},
                ListElement{ value: 0},
                ListElement{ value: 2},
                ListElement{ value: 4},
                ListElement{ value: 3}
            ]
            deviceEnabled: true
        }
        ListElement{
            deviceIndex: 4
            deviceName: qsTr("Printer")
            deviceDescription: qsTr("Qt Smart Printer")
            deviceSource: "../Apps/Printer/PrinterApp.qml"
            deviceWidget: "../Apps/Printer/PrinterWidget.qml"
            deviceRooms: [
                ListElement{ value: 3}
            ]
            deviceEnabled: true
        }
        ListElement{
            deviceIndex: 5
            deviceName: qsTr("Dishwasher")
            deviceDescription: qsTr("Qt Smart Dishwasher")
            deviceSource: "../Apps/Dishwasher/DishwasherApp.qml"
            deviceWidget: "../Apps/Dishwasher/DishwasherWidget.qml"
            deviceRooms: [
                ListElement{ value: 2}
            ]
            deviceEnabled: true
        }

        ListElement{
            deviceIndex: 6
            deviceName: qsTr("Lights")
            deviceDescription: qsTr("Qt lights control")
            deviceSource: ""
            deviceWidget: "../Apps/Lights/LightsWidget.qml"
            deviceRooms: [
                ListElement{ value: 1},
                ListElement{ value: 0},
                ListElement{ value: 2},
                ListElement{ value: 4},
                ListElement{ value: 3}
            ]
            deviceEnabled: false
        }


        ListElement{
            deviceIndex: 7
            deviceName: qsTr("Security")
            deviceDescription: qsTr("Qt security control")
            deviceSource: ""
            deviceWidget: "../Apps/Security/SecurityWidget.qml"
            deviceRooms: [
                ListElement{ value: 0}
            ]
            deviceEnabled: false
        }





    }



    ListModel{
        id: thermalProfileList
        ListElement{
            name: "Home comfort"
            icon: "Comfort.ui.qml"
            rooms:[
                ListElement{
                    name: "General"
                    nameIndex: 0
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 74
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 73
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Living room"
                    nameIndex: 1
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 74
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 73
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Bathroom"
                    nameIndex: 2
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 68
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 67
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 66
                        }

                    ]
                },
                ListElement{
                    name: "Kitchen"
                    nameIndex: 3
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 70
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 70
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                },
                ListElement{
                    name: "Office"
                    nameIndex: 4
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 78
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 76
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 74
                        }

                    ]
                },
                ListElement{
                    name: "Bedroom"
                    nameIndex: 5
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 78
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 76
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 74
                        }

                    ]
                }

            ]
        }
        ListElement{
            name: "Kids at home"
            icon: "HouseOutline.ui.qml"
            rooms:[
                ListElement{
                    name: "General"
                    nameIndex: 0
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 74
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 72
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                },
                ListElement{
                    name: "Living room"
                    nameIndex: 1
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 76
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 74
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Bathroom"
                    nameIndex: 2
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 76
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 74
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Kitchen"
                    nameIndex: 3
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 70
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 68
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 68
                        }

                    ]
                },
                ListElement{
                    name: "Office"
                    nameIndex: 4
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 76
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 74
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Bedroom"
                    nameIndex: 5
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 78
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 76
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 74
                        }

                    ]
                }

            ]
        }
        ListElement{
            name: "Summer time"
            icon: "Sun_outline.ui.qml"
            rooms:[
                ListElement{
                    name: "General"
                    nameIndex: 0
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 78
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 72
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                },
                ListElement{
                    name: "Living room"
                    nameIndex: 1
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 70
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 68
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 68
                        }

                    ]
                },
                ListElement{
                    name: "Bathroom"
                    nameIndex: 2
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 74
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 72
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                },
                ListElement{
                    name: "Kitchen"
                    nameIndex: 3
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 68
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 68
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 68
                        }

                    ]
                },
                ListElement{
                    name: "Office"
                    nameIndex: 4
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 66
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 66
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 66
                        }

                    ]
                },
                ListElement{
                    name: "Bedroom"
                    nameIndex: 5
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 68
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 68
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 68
                        }

                    ]
                }

            ]
        }
        ListElement{
            name: "Winter time"
            icon: "Freezer.ui.qml"
            rooms:[
                ListElement{
                    name: "General"
                    nameIndex: 0
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 78
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 72
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                },
                ListElement{
                    name: "Living room"
                    nameIndex: 1
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 76
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 74
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Bathroom"
                    nameIndex: 2
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 72
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 70
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                },
                ListElement{
                    name: "Kitchen"
                    nameIndex: 3
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 76
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 74
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 72
                        }

                    ]
                },
                ListElement{
                    name: "Office"
                    nameIndex: 4
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 78
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 76
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 74
                        }

                    ]
                },
                ListElement{
                    name: "Bedroom"
                    nameIndex: 5
                    temperatures: [
                        ListElement{
                            name: "Morning"
                            nameIndex: 0
                            value: 74
                        },
                        ListElement{
                            name: "Afternoon"
                            nameIndex: 1
                            value: 72
                        },
                        ListElement{
                            name: "Night"
                            nameIndex: 2
                            value: 70
                        }

                    ]
                }

            ]
        }


    }


    ListModel{
        id: dishWasherProgramsList
        ListElement{
            name: "Daily"
            value: 0
            electricity: 820
            temperature: 142
            time: 7200
            ambient: "#1E92FE"
            icon: "Daily.ui.qml"
            positionX: 0
            sizeWidth: 105

        }
        ListElement{
            name: "Eco wash"
            value: 1
            electricity: 600
            temperature: 92
            time: 5400
            ambient: "#1BEB87"
            icon: "Eco.ui.qml"
            positionX: 125
            sizeWidth: 150
        }
        ListElement{
            name: "Fast"
            value: 2
            electricity: 950
            temperature: 152
            time: 3300
            ambient: "#FCA729"
            icon: "Fast.ui.qml"
            positionX: 295
            sizeWidth: 99
        }
        ListElement{
            name: "Delicate"
            value: 3
            electricity: 650
            temperature: 92
            time: 9000
            ambient: "#FF9DFB"
            icon: "Delicate.ui.qml"
            positionX: 414
            sizeWidth: 137
        }

    }


    ListModel{
        id: roomsAppliancesList


        ListElement{
            name: "general"
            roomIndex: 0
            appliances: []
        }

        ListElement{
            name: "living"
            roomIndex: 1
            appliances: [
                ListElement{
                    value: "Light"
                },
                ListElement{
                    value: "Tv"
                },
                ListElement{
                    value: "Hi_Fi"
                }
            ]

        }

        ListElement{
            name: "bathroom"
            roomIndex: 2
            appliances: [
                ListElement{
                    value: "Light"
                }
            ]
        }

        ListElement{
            name: "kitchen"
            roomIndex: 3
            appliances: [
                ListElement{
                    value: "Light"
                },
                ListElement{
                    value: "Fridge"
                },
                ListElement{
                    value: "Dishwasher"
                }
            ]
        }

        ListElement{
            name: "office"
            roomIndex: 4
            appliances: [
                ListElement{
                    value: "Light"
                },
                ListElement{
                    value: "Printer"
                },
                ListElement{
                    value: "PC"
                }
            ]
        }

        ListElement{
            name: "bedroom"
            roomIndex: 5
            appliances: [
                ListElement{
                    value: "Light"
                }
            ]
        }

    }



    ListModel{
        id: energyMonthsList
        ListElement{
            topTextValue: "2023"
            bottomTextValue: qsTr("January")
            values: [
                ListElement{
                    timeValue: "1"
                    producedRatioValue: 60
                    consumedRatioValue: 80
                },
                ListElement{
                    timeValue: "5"
                    producedRatioValue: 55
                    consumedRatioValue: 82
                },
                ListElement{
                    timeValue: "10"
                    producedRatioValue: 78
                    consumedRatioValue: 56
                },
                ListElement{
                    timeValue: "15"
                    producedRatioValue: 96
                    consumedRatioValue: 75
                },
                ListElement{
                    timeValue: "20"
                    producedRatioValue: 88
                    consumedRatioValue: 78
                },
                ListElement{
                    timeValue: "25"
                    producedRatioValue: 69
                    consumedRatioValue: 84
                },
                ListElement{
                    timeValue: "31"
                    producedRatioValue: 76
                    consumedRatioValue: 74
                }
            ]
        }
        ListElement{
            topTextValue: "2023"
            bottomTextValue: qsTr("February")
            values: [
                ListElement{
                    timeValue: "1"
                    producedRatioValue: 76
                    consumedRatioValue: 74
                },
                ListElement{
                    timeValue: "5"
                    producedRatioValue: 75
                    consumedRatioValue: 69
                },
                ListElement{
                    timeValue: "10"
                    producedRatioValue: 78
                    consumedRatioValue: 66
                },
                ListElement{
                    timeValue: "15"
                    producedRatioValue: 86
                    consumedRatioValue: 85
                },
                ListElement{
                    timeValue: "20"
                    producedRatioValue: 78
                    consumedRatioValue: 88
                },
                ListElement{
                    timeValue: "25"
                    producedRatioValue: 79
                    consumedRatioValue: 74
                },
                ListElement{
                    timeValue: "31"
                    producedRatioValue: 76
                    consumedRatioValue: 74
                }
            ]
        }
        ListElement{
            topTextValue: "2023"
            bottomTextValue: qsTr("March")
            values: [
                ListElement{
                    timeValue: "1"
                    producedRatioValue: 95
                    consumedRatioValue: 87
                },
                ListElement{
                    timeValue: "5"
                    producedRatioValue: 67
                    consumedRatioValue: 84
                },
                ListElement{
                    timeValue: "10"
                    producedRatioValue: 69
                    consumedRatioValue: 44
                },
                ListElement{
                    timeValue: "15"
                    producedRatioValue: 0
                    consumedRatioValue: 0
                },
                ListElement{
                    timeValue: "20"
                    producedRatioValue: 0
                    consumedRatioValue: 0
                },
                ListElement{
                    timeValue: "25"
                    producedRatioValue: 0
                    consumedRatioValue: 0
                },
                ListElement{
                    timeValue: "31"
                    producedRatioValue: 0
                    consumedRatioValue: 0
                }
            ]
        }

    }



    function updateDeviceModel(selectedRoom){

        var resultModel = []
        var sz = devicesModelList.count
        filteredDevicesModelList.clear()

        for(var i = 0; i < sz; i++){

            var device = devicesModelList.get(i)


            if(selectedRoom===utils.roomsStatus.all){
                filteredDevicesModelList.append(device)

            }
            else{
                var rooms = device.deviceRooms
                var length = rooms.count

                for(var j = 0; j < length; j++){

                    var room = rooms.get(j)
                    if(room.value === selectedRoom){
                        filteredDevicesModelList.append(device)

                    }
                }
            }
        }


    }


    function getImagePath(img, svg=false){

        if(svg)
            return root.imagesPath+"/"+img+".svg"
        else
            return root.imagesPath+"/"+img+".png"

    }



    function setShortcutState(value){

        if(_shortcutStatus.value !== value){

            _shortcutStatus.value = value

            switch(value){

            case _shortcutStatus.getup:
                _lightsStatus.value = _lightsStatus.bright
                _printerStatus.value = _printerStatus.ready
                _securityStatus.value = _securityStatus.off
                _energyStatus.value = _energyStatus.comfort
                _dishWasherStatus.value = _dishWasherStatus.idle
                break;

            case _shortcutStatus.home:
                _lightsStatus.value = _lightsStatus.relax
                _printerStatus.value = _printerStatus.printing
                _securityStatus.value = _securityStatus.off
                _energyStatus.value = _energyStatus.comfort
                _dishWasherStatus.value = _dishWasherStatus.idle
                break;

            case _shortcutStatus.leave:
                _lightsStatus.value = _lightsStatus.off
                _printerStatus.value = _printerStatus.off
                _securityStatus.value = _securityStatus.on
                _energyStatus.value = _energyStatus.eco
                _dishWasherStatus.value = _dishWasherStatus.idle
                break;

            case  _shortcutStatus.sleep:
                _lightsStatus.value = _lightsStatus.off
                _printerStatus.value = _printerStatus.off
                _securityStatus.value = _securityStatus.on
                _energyStatus.value = _energyStatus.comfort
                _dishWasherStatus.value = _dishWasherStatus.pause
                break;


            }

        }

    }


    function getTimeFromSeconds(value, precise=false){

        var hh = Math.floor(value/3600)
        var remain = value%3600
        var mm = Math.floor(remain/60)
        var ss = (remain%60)

        if(mm<10)
            mm="0"+mm
        if(ss<10)
            ss="0"+ss

        if(precise)
            return hh+":"+mm+":"+ss
        else
            return hh+":"+mm

    }




    function getColorFromTemperature(value){


        var result = "#ffffff"

        if(value<66)
            result = "#696CF4"
        else if((value<72)&&(value>=66))
            result = "#DF50B1"
        else if((value<78)&&(value>=72))
            result = "#EB527C"
        else if((value<84)&&(value>=78))
            result = "#EB8A52"
        else if((value<92)&&(value>=84))
            result = "#E38E2A"

        return result

    }


    function getTemperatureValue(value){

        if(celsiusUnit)
            return Math.ceil((value-32)/2)
        else
            return value;

    }


    function getTemperatureUnit(){

        if(celsiusUnit)
            return "°C"
        else
            return "°F"

    }


    function getCurrency(){
        if(euroCurrency)
            return "€"
        else
            return "$"

    }


    //Calculate color temperature from 1500K to 11700k
    function colorByTemperature ( temp ){
        var red = 0
        var green = 0
        var blue = 0

        //Calculate Red Color
        if ( temp <= 66 ){
            red = 255
        }
        else{
            red = temp - 60
            red = 329.698727446 * Math.pow(red, -0.1332047592)
            if ( red < 0 ) red = 0
            if ( red > 255 ) red = 255
        }

        //Calculate Green Color
        if (temp <= 66){
            green = temp
            green = 99.4708025861 * Math.log(green) - 161.1195681661
            if (green < 0) green = 0
            if (green > 255) green = 255
        }
        else {
            green = temp - 60
            green = 288.1221695283 * Math.pow( green, -0.0755148492)
            if ( green < 0 ) green = 0
            if ( green > 255 ) green = 255
        }

        //Calculate Blue Color
        if (temp >= 66) {
            blue = 255
        }
        else

            if ( temp <= 19) {
                blue = 0
            }
            else {
                blue = temp - 10
                blue = 138.5177312231 * Math.log(blue) - 305.0447927307
                if ( blue < 0 ) blue = 0
                if ( blue > 255) blue = 255
            }

        return Qt.rgba(red / 255, green / 255, blue / 255)
    }




}
