#include "BtManager.h"

BtManager::BtManager(QObject *parent)
    : QObject{parent}
{

}

void BtManager::initialize()
{


    advertisingData.setDiscoverability(QLowEnergyAdvertisingData::DiscoverabilityGeneral);
    advertisingData.setIncludePowerLevel(true);
    advertisingData.setLocalName("QtSmartHome-Fridge");
   // advertisingData.setServices(QList<QBluetoothUuid>() << QBluetoothUuid::ServiceClassUuid::EnvironmentalSensing);

     m_temperature_characteristic_uuid = QBluetoothUuid(QString(BT_CHAR_FRIDGE_TEMPERATURE_UUID));
    QLowEnergyCharacteristicData charData;
    charData.setUuid(m_temperature_characteristic_uuid);
    charData.setValue(QByteArray(4, 0));
    charData.setProperties(QLowEnergyCharacteristic::Notify|QLowEnergyCharacteristic::Read|QLowEnergyCharacteristic::Write);
    const QLowEnergyDescriptorData clientConfig(QBluetoothUuid::DescriptorType::ClientCharacteristicConfiguration,
                                                QByteArray(4, 0));
    charData.addDescriptor(clientConfig);


    serviceData.setType(QLowEnergyServiceData::ServiceTypePrimary);
    serviceData.setUuid(QBluetoothUuid(QString(BT_SERVICE_UUID)));
    serviceData.addCharacteristic(charData);

    m_controller = QLowEnergyController::createPeripheral(this);
    connect(m_controller, &QLowEnergyController::errorOccurred, this, &BtManager::onErrorOccurred);
    connect(m_controller, &QLowEnergyController::disconnected, this, &BtManager::advertise);

    this->advertise();

}

void BtManager::onErrorOccurred(QLowEnergyController::Error code)
{

    qWarning().noquote().nospace() << m_controller->errorString()<< ". code: " << code;

}

void BtManager::advertise()
{
    m_service = m_controller->addService(serviceData, this);
    //  connect(m_service, &QLowEnergyService::characteristicWritten, this, &BtManager::onCharacteristicWritten);
    connect(m_service, &QLowEnergyService::characteristicChanged, this, &BtManager::onCharacteristicChanged);


    if (m_service)
    {
        m_controller->startAdvertising(QLowEnergyAdvertisingParameters(), advertisingData, advertisingData);
    }

}

void BtManager::setFridgeTemperature(int index, int value)
{
    QByteArray data(2, 0);
    data[0] = index&0xFF;
    data[1] = value&0xFF;

    QLowEnergyCharacteristic characteristic = m_service->characteristic(m_temperature_characteristic_uuid);

    m_service->writeCharacteristic(characteristic, data);


}

void BtManager::addItemToShoppingList()
{
    QByteArray data(1, 0);
    data[0] = 0xFF;

    QLowEnergyCharacteristic characteristic = m_service->characteristic(QBluetoothUuid(QString(BT_CHAR_ADD_SHOPPING_LIST_UUID)));

    m_service->writeCharacteristic(characteristic, data);
}


void BtManager::onCharacteristicChanged(const QLowEnergyCharacteristic &characteristic, const QByteArray &newValue)
{

    if(characteristic.uuid() == m_temperature_characteristic_uuid)
    {

        int index = newValue[0]&0xFF;
        int value = newValue[1]&0xFF;

        emit fridgeTemperatureUpdated(index, value);
    }
}
