#include "Manager.h"
#include "Mqtt/MqttManager.h"


Manager::Manager(QObject *parent)
    : QObject{parent}
{

    m_mqtt_manager = new MqttManager(this);

    connect(m_mqtt_manager, &MqttManager::valueUpdated, this, &Manager::onValueUpdated);
}

Manager::~Manager()
{
    delete m_mqtt_manager;
}


void Manager::setFridgeTemperature(int index, int value)
{

    QByteArray data(1, 0);
    data[0] = value&0xFF;

    QString topic = QString("%1/%2").arg(TOPIC_FRIDGE_TEMPERATURE).arg(index);

    m_mqtt_manager->writeValue(topic, data);

}



void Manager::addItemToShoppingList()
{
    QByteArray data(1, 0);
    data[0] = 0xFF;

    m_mqtt_manager->writeValue(QString(TOPIC_ADD_SHOPPING_LIST), data, false);
}

void Manager::printShoppingList()
{
    QByteArray data(1, 0);
    data[0] = 0xFF;

    m_mqtt_manager->writeValue(QString(TOPIC_PRINT_SHOPPING_LIST), data, false);
}

void Manager::onValueUpdated(const QString topic, const QByteArray &newValue)
{

    QByteArray data = QByteArray::fromHex(newValue);

    if(topic.contains(QString(TOPIC_FRIDGE_TEMPERATURE)))
    {
        if(data.length()!=1)
        {
            qDebug()<<"Wrong data format for"<<topic;
            return;
        }

        QStringList levels = topic.split("/");

        if(levels.length()==2)
        {
            int index = levels[1].toInt();
            qint8 value = data[0]&0xFF;

            emit fridgeTemperatureUpdated(index, value);
        }


    }
    else if(topic == QString(TOPIC_UPDATE_DATE_TIME))
    {
        if(data.length()!=6)
        {
            qDebug()<<"Wrong data format for"<<topic;
            return;
        }

        quint8 minutes = data[0];
        quint8 hours = data[1];
        quint8 month = data[4];
        quint8 day = data[5];

        quint8 y1 = data[2];
        quint8 y2 = data[3];

        quint16 year = y1+(256*y2);
        QDate date(year, month, day);
        QTime time(hours, minutes);


        QString date_string = date.toString("ddd, MMM d");
        QString time_string = time.toString("HH:mm");

        emit dateTimeUpdated(date_string, time_string);

    }
    else if(topic == QString(TOPIC_TEMPERATURE_UNIT))
    {
        if(data.length()!=1)
        {
            qDebug()<<"Wrong data format for"<<topic;
            return;
        }

        qint8 valueIndex = data[0]&0xFF;
        emit temperatureUnitChanged(valueIndex);
    }
    else if(topic == QString(TOPIC_CURRENCY_UNIT))
    {
        if(data.length()!=1)
        {
            qDebug()<<"Wrong data format for"<<topic;
            return;
        }

        qint8 valueIndex = data[0]&0xFF;
        emit currencyChanged(valueIndex);
    }

}


