#include "MqttManager.h"

MqttManager::MqttManager(QObject *parent)
    : QObject{parent}
{

    m_client = new QMqttClient(this);
    m_client->setHostname(QHostAddress("192.168.33.91").toString());
    m_client->setPort(1883);
    m_client->setClientId("QtSmartHome-Fridge");

    m_client->connectToHost();



    connect(m_client, &QMqttClient::stateChanged, this, &MqttManager::onStateChanged);
    connect(m_client, &QMqttClient::messageReceived, this, &MqttManager::onMessageReceived);
}

void MqttManager::onStateChanged(QMqttClient::ClientState state)
{
    QStringList topicsList;

    qDebug()<<state;
    switch (state) {
    case QMqttClient::Connected:

        topicsList << "QtSmartHome/#";
        subscribeToTopics(topicsList);
        break;

    case QMqttClient::Disconnected:
        QTimer::singleShot(10000, this, [this](){ m_client->connectToHost();});
    default:
        break;
    }
}

void MqttManager::onMessageReceived(const QByteArray &message, const QMqttTopicName &topic)
{
    QString temp = topic.name();
    QString topic_name = temp.remove("QtSmartHome/");


    if(!topic_name.isEmpty())
        emit valueUpdated(topic_name, message);
}

void MqttManager::subscribeToTopics(QStringList topics)
{

    foreach (QString topic, topics) {

        auto subscription = m_client->subscribe(topic);
        if (!subscription)
        {
            qDebug()<<"Couldn't subscribe to topic"<<topic;
        }
    }
}

void MqttManager::writeValue(QString topic, QByteArray value, bool retain)
{
   m_client->publish(QMqttTopicName("QtSmartHome/"+topic), value.toHex(), 0, retain);
}
